============
Explanations
============

.. include:: a_walk_around_the_settings.rst
.. include:: microservice_lifecycle.rst
.. include:: microservice_base_class.rst
.. include:: microservice_cookiecutter_template.rst
